@@ -8,6 +8,8 @@
 #include <cstdio>
 #include <climits>
 #include <cmath>
+#include <cstddef>
+using std::size_t;
 
 #include <R.h>
 #include <Rinternals.h>
