@@ -6,6 +6,8 @@
 #include <cstdio>
 #include <climits>
 #include <cmath>
+#include <cstddef>
+using std::size_t;
 
 #include <R.h>
 #include <Rmath.h>
