@@ -3,6 +3,9 @@
 #include <cstdio>
 #include <climits>
 #include <cmath>
+#include <cstddef>
+using std::size_t;
+
 
 #include <R.h>
 #include <Rinternals.h>
